Bongs vs. Bubblers - Toking Tools Q&A
Description: Bongs vs. Bubblers - posted in Toking Tools Q&A: I just realized I have no idea where the difference lies between the two. Sometimes I can't tell if a piece is a mini bong or a bubbler. It's easy to tell in most cases but some pieces are strange. Do bubblers have detachable bowls or is that just found in bongs? What other distinctions are there between the two?
Keywords: Bongs,Bubblers,realized,have,idea,difference,lies,between,two,Sometimes,tell,piece,mini,bong

Jump to content

- Grasscity Shop
- Grasscity Community
- Grasscity Magazine

Search

- Search section:
- This topic
- Forums
- Members
- Help Files
- Gallery
- Blogs
- Pages
- Store

Login or Sign Up now and be part of the biggest online stoners community with more than 600.000 members.

# Bongs vs. Bubblers

- by yertletheturtle420
- Dec 07 2015 12:15 AM
- 6 Replies

- Please log in to reply

- Newbie

- yertletheturtle420
- Registered Upgraded
- 6 posts

###

Posted 07 December 2015 - 12:15 AM

- #1

I just realized I have no idea where the difference lies between the two. Sometimes I can't tell if a piece is a mini bong or a bubbler. It's easy to tell in most cases but some pieces are strange.
Do bubblers have detachable bowls or is that just found in bongs?
What other distinctions are there between the two?

- ajroxit likes this

Replies (6)

### Similar Topics: Bongs vs. Bubblers x

| #### Bongs vs Bubblers vs Blunts vs Joints Tokers Q&A Started by PresidentRed , 06 Feb 2013 |  | 13 replies 1,508 views | reaperr420 07 Feb 2013
| #### Multipe chamber bubblers vs bongs... I have a few questions. Toking Tools Q&A Started by Zeusophobia , 23 Nov 2011 |  | 2 replies 1,244 views | CheechNBong420 23 Nov 2011
| #### Bubblers vs Bongs. Bongs, Bubblers, Water Pipes Started by TokeyMcBlunt , 28 Sep 2011 |  | 3 replies 2,952 views | kliff2004 28 Sep 2011
| #### SteamRoller's vs [&] Bongs/Bubblers Bongs, Bubblers, Water Pipes Started by Sm0kieee , 15 Jun 2011 1 2 |  | 23 replies 4,129 views | overheatedmud 22 Jun 2011
| #### Bongs vs Bubblers vs Spoons? Dry Pieces, Spoons and Sherlocks Started by Oedipus Rex , 18 Nov 2010 |  | 3 replies 1,015 views | Iofthehurricane 18 Nov 2010

- Ray Machine (you can smoke out of it!)

- dankness420
- Registered Upgraded
- 5,401 posts

###

Posted 07 December 2015 - 01:13 AM

- #2

Honestly I don't think it matters to much.

Too me this is a bubbler

And this is a bong

Either way I am getting stoned.

- NewSmoke15, grape and ajroxit like this

- Freed Masonic Stoner

- mistahsparklez
- Registered Upgraded
- 2,281 posts

###

Posted 07 December 2015 - 01:21 AM

- #3

The slide and pull of a bong makes it uniquely bong. Bubblers are cool too though I've owned a couple myself.

- ajroxit likes this

- Senior Member

- toaster032
- Registered Upgraded
- 652 posts

###

Posted 07 December 2015 - 01:39 AM

- #4

a bubbler is essentially a bong, but a bubbler generally has a toke-hole, instead of the slide being pull-outable like in a bong.

- ajroxit and mostdope122 like this

- Newbie

- BostonMarijuanaSupply
- Registered Upgraded
- 8 posts

###

Posted Yesterday, 10:16 PM

- #5

You will never see a bubbler with a detachable bowl, and only sometime will you see and bong with a bowl that does not detach.
Fix bowl = probably a bubbler
Detachable bowl = definitely a bong
The main difference is that there is always a downstem on a bong where there is never one on a bubbler.

- ajroxit likes this

- Senior Member

- Dr.Fumbles
- Registered Upgraded
- 1,156 posts

###

Posted Today, 12:32 PM

- #6

> You will never see a bubbler with a detachable bowl, and only sometime will you see and bong with a bowl that does not detach.
> Fix bowl = probably a bubbler
> Detachable bowl = definitely a bong
> The main difference is that there is always a downstem on a bong where there is never one on a bubbler.

That's false, lots of bubblers have removable bowls

- pecker wood

- ajroxit
- Registered Upgraded
- 2,161 posts

###

Posted Today, 02:54 PM

- #7

Bubbler is a mini bong of sorts. Most are blown glass and will easily fit in one hand unless you're paying many dollars for something heady. What makes a bubbler a bubbler in my opinion is that it looks like a spoon with a chamber for liquid. Regardless of size, it's that hand blown glass bubblers I like the best. I like them with longer stems like those Gandalf pipes we see everywhere.

Even though I don't normally go with a ceramic piece I had a ceramic bubbler that was a frog standing on a mushroom with the mushroom being the stem and the frogs back was the bowl. It wasn't a bong because of the size of water chamber which was about the size of a golf ball. So I think the way the water is enclosed and used in a smaller amount is a defining characteristic.

Man I'm pretty fucking high and it actually took me a long time to get it right in my head lol!!!

Back to Toking Tools Q&A · Next Unread Topic →

#### 2 user(s) are reading this topic

0 members, 2 guests, 0 anonymous users

Reply to quoted posts Clear

### Sign In

- Use Facebook
- Use Twitter

- Need an account? Register now!
- Username
- Password
  I've forgotten my password
- Remember me
  This is not recommended for shared computers
- Sign in anonymously
  Don't add me to the active users list
- Privacy Policy

### Network

- Grasscity Shop
- Grasscity Community
- Grasscity Magazine
- 420 Network

### Community

- Forums
- Gallery
- Blogs
- Contests

### Help

- Forum FAQ
- End User License Agreement
- Privacy Policy
- Contact Us

### Find Us On

- iPhone
  App
- Android
  App

© Copyright 1999 - 2015 420Network BV | All rights reserved